==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiWidgets/QGraphicsEffect_shell.h <==
#ifndef QGRAPHICSEFFECT_SHELL_H
#define QGRAPHICSEFFECT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpixmap.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(graphicseffect)

class QGraphicsEffect_shell : public QGraphicsEffect, public QtJambiShellInterface
{
public:
    QGraphicsEffect_shell(QObject* parent0 = nullptr);
    ~QGraphicsEffect_shell() override;

    QRectF boundingRectFor(const QRectF& sourceRect0) const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void draw(QPainter* painter0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void sourceChanged(QGraphicsEffect::ChangeFlags flags0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGraphicsEffect_access : public QGraphicsEffect
{
    void __qt_drawSource_QPainter_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0);
    jobject __qt_sourceBoundingRect_Qt_CoordinateSystem_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint system0) const;
    jboolean __qt_sourceIsPixmap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_sourcePixmap_Qt_CoordinateSystem_QPoint_ptr_QGraphicsEffect_PixmapPadMode_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint system0, QtJambiNativeID offset1, jint mode2) const;
    void __qt_updateBoundingRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_boundingRectFor_cref_QRectF_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID sourceRect0) const;
    void __qt_draw_QPainter_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0);
    void __qt_sourceChanged_QGraphicsEffect_ChangeFlags(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint flags0);
};

#endif // QT_CONFIG(graphicseffect)
#endif // QGRAPHICSEFFECT_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiWidgets/QGraphicsEffect_shell.h <==
#ifndef QGRAPHICSEFFECT_SHELL_H
#define QGRAPHICSEFFECT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpixmap.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(graphicseffect)

class QGraphicsEffect_shell : public QGraphicsEffect, public QtJambiShellInterface
{
public:
    QGraphicsEffect_shell(QObject* parent0 = nullptr);
    ~QGraphicsEffect_shell() override;

    QRectF boundingRectFor(const QRectF& sourceRect0) const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void draw(QPainter* painter0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void sourceChanged(QGraphicsEffect::ChangeFlags flags0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGraphicsEffect_access : public QGraphicsEffect
{
    void __qt_drawSource_QPainter_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0);
    jobject __qt_sourceBoundingRect_Qt_CoordinateSystem_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint system0) const;
    jboolean __qt_sourceIsPixmap_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_sourcePixmap_Qt_CoordinateSystem_QPoint_ptr_QGraphicsEffect_PixmapPadMode_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint system0, QtJambiNativeID offset1, jint mode2) const;
    void __qt_updateBoundingRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_boundingRectFor_cref_QRectF_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID sourceRect0) const;
    void __qt_draw_QPainter_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0);
    void __qt_sourceChanged_QGraphicsEffect_ChangeFlags(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint flags0);
};

#endif // QT_CONFIG(graphicseffect)
#endif // QGRAPHICSEFFECT_SHELL_H
